Package: rbranding
Title: Manage Branding and Accessibility of R Projects
Version: 0.1.1
Authors@R: c(
    person("Willy", "Ray", , "william.ray@hsc.utah.edu", role = c("aut", "cre")),
    person("Andrew", "Pulsipher", , "pulsipher.a@gmail.com", role = c("aut", "ctb"),
           comment = c(ORCID = "0000-0002-0773-3210")),
    person("Centers for Disease Control and Prevention's Center for Forecasting and Outbreak Analytics", role = "fnd",
           comment = "Cooperative agreement CDC-RFA-FT-23-0069")
  )
Description: A tool for building projects that are visually consistent,
    accessible, and easy to maintain. It provides functions for managing
    branding assets, applying organization-wide themes using 'brand.yml',
    and setting up new projects with accessibility features and correct
    branding. It supports 'quarto', 'shiny', and 'rmarkdown' projects, and
    integrates with 'ggplot2'. The accessibility features are based
    on the Web Content Accessibility Guidelines
    <https://www.w3.org/WAI/WCAG22/quickref/?versions=2.1>
    and Accessible Rich Internet Applications (ARIA) specifications
    <https://www.w3.org/WAI/ARIA/apg/>. The branding framework implements
    the 'brand.yml' specification <https://posit-dev.github.io/brand-yml/>.
License: MIT + file LICENSE
URL: https://epiforesite.github.io/rbranding/,
        https://github.com/EpiForeSITE/rbranding
BugReports: https://github.com/EpiForeSITE/rbranding/issues
Imports: credentials, ggplot2, utils, yaml
Suggests: DT, grid, here, htmltools, knitr, leaflet, pkgdown, plotly,
        png, rmarkdown, shiny, showtext, sysfonts, thematic, tinytest
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-12-08 22:11:07 UTC; runner
Author: Willy Ray [aut, cre],
  Andrew Pulsipher [aut, ctb] (ORCID:
    <https://orcid.org/0000-0002-0773-3210>),
  Centers for Disease Control and Prevention's Center for Forecasting and
    Outbreak Analytics [fnd] (Cooperative agreement CDC-RFA-FT-23-0069)
Maintainer: Willy Ray <william.ray@hsc.utah.edu>
Repository: CRAN
Date/Publication: 2025-12-08 23:40:02 UTC
Built: R 4.6.0; ; 2026-04-25 11:43:27 UTC; unix
