# Generated by roxygen2: do not edit by hand

export(brand_add_logo)
export(brand_init)
export(brand_reset_ggplot)
export(brand_set_ggplot)
export(get_brand_private_github)
export(get_brand_public)
export(get_template)
importFrom(credentials,git_credential_ask)
importFrom(tools,md5sum)
importFrom(utils,download.file)
importFrom(yaml,read_yaml)
importFrom(yaml,write_yaml)
