## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----echo=FALSE, out.width="50%", fig.alt="Screenshot of a simple branded Quarto website"----
knitr::include_graphics("vignette-screenshots/qwebsite.jpg")

## ----echo=FALSE, out.width="50%", fig.alt="Screenshot of a branded ggplot2 scatterplot figure"----
knitr::include_graphics("vignette-screenshots/qggplot2.jpg")

## ----echo=FALSE, out.width="50%", fig.alt="Screenshot of a simple branded Shiny app histogram"----
knitr::include_graphics("vignette-screenshots/shiny2.jpg")

## ----echo=FALSE, out.width="50%", fig.alt="Screenshot of a simple branded Shiny app K-means clustering visualization"----
knitr::include_graphics("vignette-screenshots/kmeans.jpg")

## ----echo=FALSE, out.width="50%", fig.alt="Screenshot of a complex branded Shiny app histogram"----
knitr::include_graphics("vignette-screenshots/shinyapp.jpg")

## ----echo=FALSE, out.width="50%", fig.alt="Screenshot of a complex branded Shiny app visualizing wastewater data"----
knitr::include_graphics("vignette-screenshots/wastewater.jpg")

## ----echo=FALSE, out.width="50%", fig.alt="Screenshot of a simple branded R Markdown document"----
knitr::include_graphics("vignette-screenshots/rmark.jpg")

